@@ -424,7 +424,7 @@ if ( length(unique(dfrm[,1]))==2 && is.factor(dfrm[,2]) ) {
 
 	# In case the misc. level consists only of only NA rename it 'Missing'
 	if ( length(which(look.up.table[,2]=='Missing'))==1 && (length(which(look.up.table[,1]=="misc. level neg."))==1 || length(which(look.up.table[,1]=="misc. level pos."))==1) ) {
-		if ( (which(look.up.table[,2]=='Missing') == which(look.up.table[,1]=='misc. level pos.')) || (which(look.up.table[,2]=='Missing') == which(look.up.table[,1]=='misc. level pos.')) ) {
+		if ( (which(look.up.table[,2]=='Missing') == which(look.up.table[,1]=='misc. level neg.')) || (which(look.up.table[,2]=='Missing') == which(look.up.table[,1]=='misc. level pos.')) ) {
 			levels(look.up.table[,1]) <- c(levels(look.up.table[,2]), 'Missing')   # add factor level 'Missing'
 			look.up.table[,1][look.up.table[,2]=='Missing'] <- 'Missing'
 		}
@@ -467,16 +467,14 @@ else {
 
 
 
-#' @title Generation of Binning
+#' @title Binning via Fine and Coarse Classing
 #'
 #' @description
-#' \code{woe.binning} generates a supervised binning of numeric variables and factors
-#' with respect to a dichotomous target variable.
+#' \code{woe.binning} generates a supervised fine and coarse classing of numeric
+#' variables and factors with respect to a dichotomous target variable. Its parameters
+#' provide flexibility in finding a binning that fits specific data characteristics
+#' and practical needs.
 #'
-#' @details
-#' \code{woe.binning} generates a supervised binning of numeric variables and factors with
-#' respect to a dichotomous target variable. Its parameters provide flexibility in
-#' finding a binning that fits specific data characteristics and practical needs.
 #' @section Binning of Numeric Variables:
 #' Numeric variables (continuous and ordinal) are binned by merging initial classes with
 #' similar frequencies. The number of initial bins results from the \emph{min.perc.total}
@@ -487,7 +485,8 @@ else {
 #' the next upper bin, and in case of the last bin with the next lower one. NAs have
 #' their own bin and will not be merged with others. Finally nearby bins with most similar
 #' weight of evidence (WOE) values are joined step by step until the information value
-#' (IV) decreases more than specified by a percentage value (\emph{stop.limit} parameter).
+#' (IV) decreases more than specified by a percentage value (\emph{stop.limit} parameter)
+#' or until two bins are reached.
 #' @section Binning of Factors:
 #' Factors (categorical variables) are binned by merging factor levels. As a start sparse
 #' levels (defined via the \emph{min.perc.total} and \emph{min.perc.class} parameters)
@@ -496,7 +495,8 @@ else {
 #' values), respectively as \sQuote{misc. level neg.} (associated with negative WOE
 #' values). In case a misc. level contains only NAs it will be named \sQuote{Missing}.
 #' Afterwards levels with similar WOE values are joined step by step until the information
-#' value (IV) decreases more than specified by a percentage value (\emph{stop.limit} parameter).
+#' value (IV) decreases more than specified by a percentage value (\emph{stop.limit} parameter)
+#' or until two bins are reached.
 #' @section Adjustment of 0 Frequencies:
 #' In case the crosstab of the bins with the target classes contains frequencies = 0
 #' the column percentages are adjusted to be able to compute the WOE and IV values:
@@ -576,7 +576,7 @@ else {
 #' disease. Use integers (e.g. 1) or characters in quotes (e.g. \dQuote{bad}).
 #' This class will be represented by negative WOE values then.
 #' 
-#' @family woe binning functions
+#' @family binning functions
 #' 
 #' @examples
 #' # Load German credit data and create subset
@@ -595,6 +595,7 @@ else {
 #'                        abbrev.fact.levels=50, event.class='bad')
 #'
 #' # Bin two variables (one numeric and one factor)
+#' # with default parameter settings
 #' binning <- woe.binning(df, 'creditability', c('credit.amount','purpose'))
 #'
 #' # Bin all variables of the data frame (apart from the target variable)
@@ -616,13 +617,25 @@ woe.binning <- function(df, target.var, pred.var, min.perc.total, min.perc.class
 	#### Warning message and defaults in case parameters are not specified
 	if ( missing(df)==TRUE || missing(target.var)==TRUE || missing(pred.var)==TRUE ) { warning("Incorrect specification of data frame and/or variables.") }	
 	if ( missing(min.perc.total)==TRUE ) { min.perc.total=0.05 }
-	if ( min.perc.total<0.01 || min.perc.total>0.2 || !is.numeric(min.perc.total) ) { warning("Incorrect parameter specification; accepted min.perc.total parameter range is 0.01-0.2.") }
+	if ( min.perc.total<0.01 || min.perc.total>0.2 || !is.numeric(min.perc.total) ) {
+		warning("Incorrect parameter specification; accepted min.perc.total parameter range is 0.01-0.2. Parameter was set to default (0.05).")
+		min.perc.total=0.05
+	}
 	if ( missing(min.perc.class)==TRUE ) { min.perc.class=0 }
-	if ( min.perc.class<0 || min.perc.class>0.2 || !is.numeric(min.perc.class) ) { warning("Incorrect parameter specification; accepted min.perc.class parameter range is 0-0.2.") }	
+	if ( min.perc.class<0 || min.perc.class>0.2 || !is.numeric(min.perc.class) ) {
+		warning("Incorrect parameter specification; accepted min.perc.class parameter range is 0-0.2. Parameter was set to default (0).")
+		min.perc.class=0
+	}
 	if ( missing(stop.limit)==TRUE ) { stop.limit=0.1 }
-	if ( stop.limit<0 || stop.limit>0.5 || !is.numeric(stop.limit) ) { warning("Incorrect parameter specification; accepted stop.limit parameter range is 0-0.05.") }	
+	if ( stop.limit<0 || stop.limit>0.5 || !is.numeric(stop.limit) ) {
+		warning("Incorrect parameter specification; accepted stop.limit parameter range is 0-0.05. Parameter was set to default (0.1).")
+		stop.limit=0.1
+	}
 	if ( missing(abbrev.fact.levels)==TRUE ) { abbrev.fact.levels=200 }
-	if ( abbrev.fact.levels<0 || abbrev.fact.levels>1000 || !is.numeric(stop.limit) ) { warning("Incorrect parameter specification; accepted abbrev.fact.levels parameter range is 0-10000.") }
+	if ( abbrev.fact.levels<0 || abbrev.fact.levels>1000 ) {
+		warning("Incorrect parameter specification; accepted abbrev.fact.levels parameter range is 0-10000. Parameter was set to default (200).")
+		abbrev.fact.levels=200
+	}
 
 	#### Display warning message in case of incorrect target variable specification
 	if ( !(length(unique(df[,target.var][!is.na(df[,target.var])]))==2) ) {
